==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.odf/src/com/openexchange/office/odf/ConfigItemMapNamed.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.odf;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map.Entry;

import org.apache.xml.serializer.SerializationHandler;
import org.odftoolkit.odfdom.IElementWriter;
import org.odftoolkit.odfdom.dom.attribute.config.ConfigNameAttribute;
import org.odftoolkit.odfdom.dom.element.config.ConfigConfigItemMapNamedElement;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

public class ConfigItemMapNamed implements IElementWriter {

	final String name;

	final HashMap<String, ConfigItemMapEntry> items = new HashMap<String, ConfigItemMapEntry>();

	public ConfigItemMapNamed(String name) {
		this.name = name;
	}

	public ConfigItemMapNamed(String name, Attributes attributes) {
		this.name = name;
	}

	public HashMap<String, ConfigItemMapEntry> getItems() {
		return items;
	}

	@Override
	public void writeObject(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.startElement(output, ConfigConfigItemMapNamedElement.ELEMENT_NAME);
		if(name!=null&&!name.isEmpty()) {
			SaxContextHandler.addOdfAttribute(output, ConfigNameAttribute.ATTRIBUTE_NAME, null, name);
		}
		final Iterator<Entry<String, ConfigItemMapEntry>> itemIter = items.entrySet().iterator();
		while(itemIter.hasNext()) {
			final Entry<String, ConfigItemMapEntry> item = itemIter.next();
			item.getValue().writeObject(output);
		}
		SaxContextHandler.endElement(output, ConfigConfigItemMapNamedElement.ELEMENT_NAME);
	}
}

==> open-xchange-documents-backend_7.8.3.orig.tar.bz2: open-xchange-documents-backend-7.8.3/com.openexchange.office.odf/src/com/openexchange/office/odf/ConfigItemMapNamed.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.odf;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map.Entry;

import org.apache.xml.serializer.SerializationHandler;
import org.odftoolkit.odfdom.IElementWriter;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

public class ConfigItemMapNamed implements IElementWriter {

	final String name;

	final HashMap<String, ConfigItemMapEntry> items = new HashMap<String, ConfigItemMapEntry>();

	public ConfigItemMapNamed(String name) {
		this.name = name;
	}

	public ConfigItemMapNamed(String name, Attributes attributes) {
		this.name = name;
	}

	public HashMap<String, ConfigItemMapEntry> getItems() {
		return items;
	}

	@Override
	public void writeObject(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.startElement(output, Namespaces.CONFIG, "config-item-map-named", "config:config-item-map-named");
		if(name!=null&&!name.isEmpty()) {
			SaxContextHandler.addAttribute(output, Namespaces.CONFIG, "name", "config:name", name);
		}
		final Iterator<Entry<String, ConfigItemMapEntry>> itemIter = items.entrySet().iterator();
		while(itemIter.hasNext()) {
			final Entry<String, ConfigItemMapEntry> item = itemIter.next();
			item.getValue().writeObject(output);
		}
		SaxContextHandler.endElement(output, Namespaces.CONFIG, "config-item-map-named", "config:config-item-map-named");
	}
}
